==> linux-show-player_0.5.orig.tar.gz: linux-show-player-0.5/lisp/modules/action_cues/i18n/action_cues_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>CollectionCue</name>
    <message>
        <location filename="../collection_cue.py" line="76"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="80"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="143"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="143"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
</context>
<context>
    <name>CommandCue</name>
    <message>
        <location filename="../command_cue.py" line="79"/>
        <source>Process ended with an error status.</source>
        <translation>Le process s&apos;est terminé par une erreur </translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="79"/>
        <source>Exit code: </source>
        <translation>Code de sortie :</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="123"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="124"/>
        <source>Command to execute, as in a shell</source>
        <translation>Commande à exécuter, comme dans un terminal</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="126"/>
        <source>Discard command output</source>
        <translation>Abandonner la sortie de commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="128"/>
        <source>Ignore command errors</source>
        <translation>Ignorer les erreurs de commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="130"/>
        <source>Kill instead of terminate</source>
        <translation>Killer au lieu de terminer</translation>
    </message>
</context>
<context>
    <name>CueName</name>
    <message>
        <location filename="../command_cue.py" line="39"/>
        <source>Command Cue</source>
        <translation>Cue de commande</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="34"/>
        <source>MIDI Cue</source>
        <translation>Cue MIDI</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="43"/>
        <source>Volume Control</source>
        <translation>Contrôle du Volume</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="36"/>
        <source>Seek Cue</source>
        <translation>Recherche de Cue</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="36"/>
        <source>Collection Cue</source>
        <translation>Collection de cue</translation>
    </message>
    <message>
        <location filename="../stop_all.py" line="33"/>
        <source>Stop-All</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="33"/>
        <source>Index Action</source>
        <translation>Index d&apos;action</translation>
    </message>
</context>
<context>
    <name>IndexActionCue</name>
    <message>
        <location filename="../index_action_cue.py" line="94"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="95"/>
        <source>Use a relative index</source>
        <translation>Utiliser un index relatif</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="97"/>
        <source>Target index</source>
        <translation>Index cible</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="99"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
</context>
<context>
    <name>MIDICue</name>
    <message>
        <location filename="../midi_cue.py" line="116"/>
        <source>MIDI Message</source>
        <translation>Message MIDI</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="117"/>
        <source>Message type</source>
        <translation>Type de message</translation>
    </message>
</context>
<context>
    <name>SeekCue</name>
    <message>
        <location filename="../seek_cue.py" line="93"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="94"/>
        <source>Click to select</source>
        <translation>Cliquer pour sélectionner</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="95"/>
        <source>Not selected</source>
        <translation>Non sélectionné</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="96"/>
        <source>Seek</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="97"/>
        <source>Time to reach</source>
        <translation>Temps à atteindre</translation>
    </message>
</context>
<context>
    <name>SettingsPageName</name>
    <message>
        <location filename="../command_cue.py" line="97"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="54"/>
        <source>MIDI Settings</source>
        <translation>Préférences MIDI</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="122"/>
        <source>Volume Settings</source>
        <translation>Préférences de volume</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="54"/>
        <source>Seek Settings</source>
        <translation>Préférences de recherche</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="54"/>
        <source>Edit Collection</source>
        <translation>Editer la collection</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="58"/>
        <source>Action Settings</source>
        <translation>Paramètres d&apos;action</translation>
    </message>
    <message>
        <location filename="../stop_all.py" line="65"/>
        <source>Stop Settings</source>
        <translation>Paramètres d&apos;arrêt</translation>
    </message>
</context>
<context>
    <name>StopAll</name>
    <message>
        <location filename="../stop_all.py" line="87"/>
        <source>Stop Action</source>
        <translation>Action d&apos;arrêt</translation>
    </message>
</context>
<context>
    <name>VolumeControl</name>
    <message>
        <location filename="../volume_control.py" line="112"/>
        <source>Error during cue execution</source>
        <translation>Erreur lors de l&apos;exécution de la cue</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="182"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="183"/>
        <source>Click to select</source>
        <translation>Cliquer pour sélectionner</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="184"/>
        <source>Not selected</source>
        <translation>Non sélectionné</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="185"/>
        <source>Volume to reach</source>
        <translation>Volume à atteindre</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="186"/>
        <source>Fade</source>
        <translation>Fondu</translation>
    </message>
</context>
</TS>

==> linux-show-player_0.5.3.orig.tar.gz: linux-show-player-0.5.3/lisp/modules/action_cues/i18n/action_cues_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.0">
<context>
    <name>CollectionCue</name>
    <message>
        <location filename="../collection_cue.py" line="76"/>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="80"/>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="143"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="143"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
</context>
<context>
    <name>CommandCue</name>
    <message>
        <location filename="../command_cue.py" line="79"/>
        <source>Process ended with an error status.</source>
        <translation>Le process s&apos;est terminé par une erreur </translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="79"/>
        <source>Exit code: </source>
        <translation>Code de sortie :</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="123"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="124"/>
        <source>Command to execute, as in a shell</source>
        <translation>Commande à exécuter, comme dans un terminal</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="126"/>
        <source>Discard command output</source>
        <translation>Abandonner la sortie de commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="128"/>
        <source>Ignore command errors</source>
        <translation>Ignorer les erreurs de commande</translation>
    </message>
    <message>
        <location filename="../command_cue.py" line="130"/>
        <source>Kill instead of terminate</source>
        <translation>Killer au lieu de terminer</translation>
    </message>
</context>
<context>
    <name>CueName</name>
    <message>
        <location filename="../command_cue.py" line="39"/>
        <source>Command Cue</source>
        <translation>Cue de commande</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="34"/>
        <source>MIDI Cue</source>
        <translation>Cue MIDI</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="43"/>
        <source>Volume Control</source>
        <translation>Contrôle du volume</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="36"/>
        <source>Seek Cue</source>
        <translation>Recherche de cue</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="36"/>
        <source>Collection Cue</source>
        <translation>Collection de cues</translation>
    </message>
    <message>
        <location filename="../stop_all.py" line="33"/>
        <source>Stop-All</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="33"/>
        <source>Index Action</source>
        <translation>Index d&apos;action</translation>
    </message>
</context>
<context>
    <name>IndexActionCue</name>
    <message>
        <location filename="../index_action_cue.py" line="94"/>
        <source>Index</source>
        <translation>Index</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="95"/>
        <source>Use a relative index</source>
        <translation>Utiliser un index relatif</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="97"/>
        <source>Target index</source>
        <translation>Index cible</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="99"/>
        <source>Action</source>
        <translation>Action</translation>
    </message>
</context>
<context>
    <name>MIDICue</name>
    <message>
        <location filename="../midi_cue.py" line="116"/>
        <source>MIDI Message</source>
        <translation>Message MIDI</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="117"/>
        <source>Message type</source>
        <translation>Type de message</translation>
    </message>
</context>
<context>
    <name>SeekCue</name>
    <message>
        <location filename="../seek_cue.py" line="93"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="94"/>
        <source>Click to select</source>
        <translation>Cliquer pour sélectionner</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="95"/>
        <source>Not selected</source>
        <translation>Non sélectionné</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="96"/>
        <source>Seek</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="97"/>
        <source>Time to reach</source>
        <translation>Temps à atteindre</translation>
    </message>
</context>
<context>
    <name>SettingsPageName</name>
    <message>
        <location filename="../command_cue.py" line="97"/>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <location filename="../midi_cue.py" line="54"/>
        <source>MIDI Settings</source>
        <translation>Préférences MIDI</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="122"/>
        <source>Volume Settings</source>
        <translation>Préférences de volume</translation>
    </message>
    <message>
        <location filename="../seek_cue.py" line="54"/>
        <source>Seek Settings</source>
        <translation>Préférences de recherche</translation>
    </message>
    <message>
        <location filename="../collection_cue.py" line="54"/>
        <source>Edit Collection</source>
        <translation>Editer la collection</translation>
    </message>
    <message>
        <location filename="../index_action_cue.py" line="58"/>
        <source>Action Settings</source>
        <translation>Paramètres d&apos;action</translation>
    </message>
    <message>
        <location filename="../stop_all.py" line="65"/>
        <source>Stop Settings</source>
        <translation>Paramètres d&apos;arrêt</translation>
    </message>
</context>
<context>
    <name>StopAll</name>
    <message>
        <location filename="../stop_all.py" line="87"/>
        <source>Stop Action</source>
        <translation>Action d&apos;arrêt</translation>
    </message>
</context>
<context>
    <name>VolumeControl</name>
    <message>
        <location filename="../volume_control.py" line="112"/>
        <source>Error during cue execution</source>
        <translation>Erreur lors de l&apos;exécution de la cue</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="182"/>
        <source>Cue</source>
        <translation>Cue</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="183"/>
        <source>Click to select</source>
        <translation>Cliquer pour sélectionner</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="184"/>
        <source>Not selected</source>
        <translation>Non sélectionné</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="185"/>
        <source>Volume to reach</source>
        <translation>Volume à atteindre</translation>
    </message>
    <message>
        <location filename="../volume_control.py" line="186"/>
        <source>Fade</source>
        <translation>Fondu</translation>
    </message>
</context>
</TS>
